@@ -8,7 +8,7 @@ from typing import List
 import aiohttp
 
 from aioazuredevops.core import DevOpsLinks, DevOpsProject, DevOpsTeam
-from aioazuredevops.builds import DevOpsBuild, DevOpsBuildLinks
+from aioazuredevops.builds import DevOpsBuild, DevOpsBuildDefinition, DevOpsBuildLinks
 
 
 class DevOpsClient:
@@ -60,18 +60,18 @@ class DevOpsClient:
                 json["url"],
                 json["state"],
                 json["revision"],
-                DevOpsLinks(
-                    json["_links"]["self"]["href"],
-                    json["_links"]["collection"]["href"],
-                    json["_links"]["web"]["href"],
-                ),
                 json["visibility"],
+                datetime.strptime(json["lastUpdateTime"], "%Y-%m-%dT%H:%M:%S.%fZ"),
                 DevOpsTeam(
                     json["defaultTeam"]["id"],
                     json["defaultTeam"]["name"],
                     json["defaultTeam"]["url"],
                 ),
-                datetime.strptime(json["lastUpdateTime"], "%Y-%m-%dT%H:%M:%S.%fZ"),
+                DevOpsLinks(
+                    json["_links"]["self"]["href"],
+                    json["_links"]["collection"]["href"],
+                    json["_links"]["web"]["href"],
+                ),
             )
 
     async def get_builds(
@@ -111,6 +111,28 @@ class DevOpsClient:
                         build["queueTime"],
                         build["startTime"],
                         build["finishTime"],
+                        DevOpsBuildDefinition(
+                            build["definition"]["id"],
+                            build["definition"]["name"],
+                            build["definition"]["url"],
+                            build["definition"]["path"],
+                            build["definition"]["type"],
+                            build["definition"]["queueStatus"],
+                            build["definition"]["revision"],
+                        ),
+                        DevOpsProject(
+                            build["project"]["id"],
+                            build["project"]["name"],
+                            build["project"]["description"],
+                            build["project"]["url"],
+                            build["project"]["state"],
+                            build["project"]["revision"],
+                            build["project"]["visibility"],
+                            datetime.strptime(
+                                build["project"]["lastUpdateTime"],
+                                "%Y-%m-%dT%H:%M:%S.%fZ",
+                            ),
+                        ),
                     )
                 )
 
@@ -150,4 +172,25 @@ class DevOpsClient:
                 build["queueTime"],
                 build["startTime"],
                 build["finishTime"],
+                DevOpsBuildDefinition(
+                    build["definition"]["id"],
+                    build["definition"]["name"],
+                    build["definition"]["url"],
+                    build["definition"]["path"],
+                    build["definition"]["type"],
+                    build["definition"]["queueStatus"],
+                    build["definition"]["revision"],
+                ),
+                DevOpsProject(
+                    build["project"]["id"],
+                    build["project"]["name"],
+                    build["project"]["description"],
+                    build["project"]["url"],
+                    build["project"]["state"],
+                    build["project"]["revision"],
+                    build["project"]["visibility"],
+                    datetime.strptime(
+                        build["project"]["lastUpdateTime"], "%Y-%m-%dT%H:%M:%S.%fZ",
+                    ),
+                ),
             )
